#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - mariadb55 installation
#
# Creation   :  2017-05-07 holbru
# Last update:  $Id: install.sh 106760 2023-10-11 12:55:14Z hbfl $
#
# Copyright (c) 2017-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=mariadb55

my_path=55

# ---------------------------------------------------------------------------
# activate tmpfiles
# ---------------------------------------------------------------------------
if [ -f /usr/bin/systemd-tmpfiles ]
then
    systemd-tmpfiles --create mariadb55.conf
fi

# ---------------------------------------------------------------------------
# create symlink to /usr/share/mysql
# ---------------------------------------------------------------------------
# move in new folder
if [ -f  /etc/config.d/mariadb ]
then
    . /etc/config.d/mariadb

    datadir='/srv/mysql/55'

    if [ "${MARIADB_DATADIR}" = "/var/lib/mysql" ] ||
       [ -z "${MARIADB_DATADIR}"  ]
    then
        mkdir -p ${datadir}

        db_list=$(ls -1 /var/lib/mysql | grep -v 'backup.pwd' )

        for FNAME in ${db_list}
        do
            if [ -d "/var/lib/mysql/${FNAME}" ]
            then
                cp -R --preserve /var/lib/mysql/${FNAME} ${datadir}/${FNAME}
                rm -rf /var/lib/mysql/${FNAME}
            else
                cp --preserve /var/lib/mysql/${FNAME} ${datadir}/${FNAME}
                rm -f /var/lib/mysql/${FNAME}
            fi
        done

    fi

    backupdir="/srv/mysql_backup/${my_path}"

    if [ "${MARIADB_BACKUP_TARGET}" = "/var/lib/mysql_backup" ]
    then
        mkdir -p ${backupdir}

        db_list=$(ls -1 /var/lib/mysql_backup )

        for FNAME in ${db_list}
        do
            cp --preserve /var/lib/mysql_backup/${FNAME} ${backupdir}/${FNAME}
            rm -f /var/lib/mysql_backup/${FNAME}
        done

        rmdir --ignore-fail-on-non-empty /var/lib/mysql_backup 2>/dev/null
    fi

    . /var/install/include/eislib
    echo
    mecho --warn 'The default database folder has changed,'
    mecho --warn 'please read the changes for more information.'
    echo
    anykey
fi

# ---------------------------------------------------------------------------
# Create log file folder
# ---------------------------------------------------------------------------
mkdir -p /var/log/mysqld/${my_path}

log_files=$(ls -1 /var/log/mysqld/mysqld.log* 2>/dev/null)

if [ -n "${log_files}" ]
then
    for line in ${log_files}
    do
        mv ${line} /var/log/mysqld/${my_path}/
    done
fi

chown -R mysql:mysql /var/log/mysqld

# ---------------------------------------------------------------------------
# link binaries to /usr/bin, if required, used update-alternatives
# ---------------------------------------------------------------------------
shopt -s nullglob
for FILE in /usr/lib/mysql/55/bin/*
do
    NAME=$(basename ${FILE})

    if [ "${NAME}" != "mysql" ]
    then
        DIR=/usr/bin
        SLAVES="${SLAVES} --slave ${DIR}/${NAME} ${NAME} ${FILE}"
    fi
done

if [ -n "${SLAVES}" ]
then
    update-alternatives --quiet --install \
    /usr/bin/mysql mysql /usr/lib/mysql/55/bin/mysql 55 \
    ${SLAVES}
fi


# ---------------------------------------------------------------------------
# Create default config
# ---------------------------------------------------------------------------
if [ -f "/etc/config.d/${package_name}" ] || [ -f "/etc/config.d/mariadb" ]
then
    update=true
else
    /usr/bin/mkdir -p /srv/mysql/${my_path}/
    echo "datetime" >/srv/mysql/${my_path}/new-install
fi

/var/install/config.d/${package_name}-update.sh

/usr/bin/rm -f /var/install/config.d/${package_name}-update.sh
/usr/bin/rm -f /etc/config.d/mariadb

# ---------------------------------------------------------------------------
# start package with update
# ---------------------------------------------------------------------------
if ${update:-false}
then
    # Make file /etc/mysql/my55.cnf
    /var/install/config.d/${package_name}.sh

    . /etc/config.d/${package_name}

    # start MySQL internal installscript
    /usr/lib/mysql/${my_path}/bin/mysql_install_db \
       --basedir=/usr/lib/mysql/${my_path} \
       --defaults-file=/etc/mysql/my${my_path}.cnf >/dev/null 2>&1

    # change user and group after run mysql_install_db!
    /usr/bin/chown -R mysql:mysql "${MARIADB55_DATADIR:-/srv/mysql/${my_path}}"
    /usr/bin/chown -R mysql:${MARIADB55_BACKUP_GROUP:-mysql} "${MARIADB55_BACKUP_TARGET}"

    /var/install/bin/mysql-common-tools-update-db --project ${package_name}
fi

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
