#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/preinstall.sh - mariadb55 preinstallation
#
# Creation   :  2017-05-07 holbru
# Last update:  $Id: preinstall.sh 106754 2023-10-10 13:46:44Z hbfl $
#
# Copyright (c) 2017-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=mariadb55

# ---------------------------------------------------------------------------
# check installed version
# ---------------------------------------------------------------------------
inst_version='mysql'

for p_inst in ${inst_version}
do
    old_mysql=$(eisman check ${p_inst} 2.6.9)
    if [ "${old_mysql}" = "installed" ]
    then
        eisman uninstall --auto --force ${p_inst}
    fi

    installed=$(eisman check ${p_inst} 2.11.0)

    case ${installed} in
    new)
        . /var/install/include/eislib

        echo
        mecho --warn    'To guarantee that the package will work correctly, please '
        mecho -n --warn 'update the following package '
        mecho -n --std  "'${p_inst}' "
        mecho --warn    'first.'
        echo
        anykey
        exit 1
        ;;
    *)
        :
        ;;
    esac
done

# ---------------------------------------------------------------------------
# remove uneeded mariadb-client package, if installed
# ---------------------------------------------------------------------------
mariadb_client=$(eisman check mariadb-client)
if [ "${mariadb_client}" = "installed" ]
then
    /usr/bin/rm -f /var/install/deinstall/mariadb-client
    eisman uninstall --auto --force mariadb-client
fi

# ---------------------------------------------------------------------------
# update system
# ---------------------------------------------------------------------------
#if [ -f "/var/install/packages/${package_name}" ]
#then
#    /var/install/bin/del-package --update -p ${package_name}
#fi

/var/install/bin/del-menu \
            setup.services.menu \
            setup.services.mariadb.menu

# ---------------------------------------------------------------------------
# switch to systemd
# ---------------------------------------------------------------------------

if [ -f /etc/init.d/${package_name} ]
then
     /usr/sbin/service stop ${package_name}
     /usr/sbin/service disable ${package_name}
     /usr/bin/rm -f /etc/rc2.d/*${package_name}
     /usr/bin/rm -f /etc/init.d/${package_name}
     /usr/sbin/service daemon-reload
     /usr/bin/sed -i '/^\/etc\/init.d\//d' /var/install/deinstall/${package_name}
fi

exit 0
# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
