#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/MARIADB55-update.sh - MARIADB55 parameter update script
#
# Creation:     2004-08-12 jv
# Last Update:  $Id: mariadb55-update.sh 106885 2023-10-19 09:31:05Z hbfl $
#
# Copyright (c) 2004 Jens Vehlhaber jens(at)eisfair(dot)org
# Copyright (c) 2011-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

# set package name
package_name=mariadb55

# include configlib
. /var/install/include/configlib

VERSION=3.4.1

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_MARIADB55='no'
    MARIADB55_NETWORK='no'
    MARIADB55_CONNECT_PORT=''

    MARIADB55_DATADIR='/srv/mysql/55'
    MARIADB55_SEND_MAIL_FROM=''
    MARIADB55_BACKUP_SCHEDULE_TIME='*-*-* 01:15:00'
    MARIADB55_BACKUP_TARGET="/srv/mysql_backup/55"
    MARIADB55_BACKUP_GROUP=''
    MARIADB55_BACKUP_N='1'
    MARIADB55_BACKUP_1_NAME=''
    MARIADB55_BACKUP_1_ACTIVE='no'
    MARIADB55_BACKUP_1_FILE='mysql'
    MARIADB55_BACKUP_1_MAX='7'
    MARIADB55_BACKUP_1_FORCE='yes'
    MARIADB55_BACKUP_MOUNT=''
    MARIADB55_BACKUP_UMOUNT=''
    MARIADB55_DEFAULT_COLLATION='utf8_unicode_ci'
    MARIADB55_BIND_IP_ADDRESS=''
    MARIADB55_MEMORY_OPT='medium'
    MARIADB55_THREAD_STACK_SIZE='256k'
    MARIADB55_MAX_ALLOWED_PACKET='1'
    MARIADB55_MAX_CONNECTIONS='200'
    MARIADB55_ACTIVATE_BINLOG='no'
    MARIADB55_MAX_BINLOG_SIZE='1024000'
}

# ---------------------------------------------------------------------------
# rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi

    # read old values from mariadb
    if [ -f /etc/config.d/mariadb ]
    then
        /var/install/bin/backup-file --quiet mariadb
        . /etc/config.d/mariadb
        old_conf=true
        rm -f /etc/config.d/mariadb
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file=$1
    {
    # -----------------------------------------------------------------------
    printgpl --conf ${package_name} '2015-09-18' 'hbfl' 'Holger Bruenjes, holgerbruenjes(at)gmx(dot)net'
    # -----------------------------------------------------------------------
    echo "# MARIADB55-VERSION ${VERSION}"

    # -----------------------------------------------------------------------
    printgroup 'General settings'
    # -----------------------------------------------------------------------


    if ${old_conf:-false}
    then
        START_MARIADB55="${START_MARIADB}"
        MARIADB55_CONNECT_PORT="${MARIADB_CONNECT_PORT}"
        MARIADB55_NETWORK="${MARIADB_NETWORK}"
        MARIADB55_DATADIR="${MARIADB_DATADIR}"
        MARIADB55_SEND_MAIL_FROM="${MARIADB_SEND_MAIL_FROM}"

        if [ "${MARIADB55_DATADIR}" = '/var/lib/mysql' ] ||
           [ -z "${MARIADB55_DATADIR}"  ]
        then
            MARIADB55_DATADIR='/srv/mysql/55'
        fi
    fi

    printvar 'START_MARIADB55'
    printcomment            "start MARIADB55 Server 'yes' or 'no'"

    printvar 'MARIADB55_NETWORK'
    printcomment            'enable the TCP/IP external connection'

    printvar 'MARIADB55_CONNECT_PORT'
    printcomment            'MARIADB55 remote port  default=3306'
    printcomment            'connect port is also uniq indentifier'

    printvar 'MARIADB55_DATADIR'
    printcomment            'empty: default /srv/mysql/55 or datadir'

    printvar 'MARIADB55_SEND_MAIL_FROM'
    printcomment            'Mail address from Admin, required for'
    printcomment            'outgoing mal'


    # -----------------------------------------------------------------------
    printgroup 'Backup settings'
    # -----------------------------------------------------------------------


    if ${old_conf:-false}
    then
        MARIADB55_BACKUP_CRON_SCHEDULE="${MARIADB_BACKUP_CRON_SCHEDULE}"
        MARIADB55_BACKUP_TARGET="${MARIADB_BACKUP_TARGET}"
        MARIADB55_BACKUP_GROUP="${MARIADB_BACKUP_GROUP}"
        MARIADB55_BACKUP_N="${MARIADB_BACKUP_N}"

        if [ "${MARIADB55_BACKUP_TARGET}" = '/var/lib/mysql_backup' ]
        then
            MARIADB55_BACKUP_TARGET='/srv/mysql_backup/55'
        fi
    fi

    printvar 'MARIADB55_BACKUP_SCHEDULE_TIME'
    printcomment            'start time for backup'

    printvar 'MARIADB55_BACKUP_TARGET'
    printcomment            'backup target directory'

    printvar 'MARIADB55_BACKUP_GROUP'
    printcomment            'special group to use the backup files'
    printcomment            'default: empty -> mysql'

    printvar 'MARIADB55_BACKUP_N'
    printcomment            'number of backup files'


    count=1
    while [ ${count} -le ${MARIADB55_BACKUP_N} ]
    do
        if ${old_conf:-false}
        then
            eval MARIADB55_BACKUP_${count}_ACTIVE='yes'
            eval MARIADB55_BACKUP_${count}_FILE='${MARIADB_BACKUP_'${count}'_FILE}'
            eval MARIADB55_BACKUP_${count}_MAX='${MARIADB_BACKUP_'${count}'_MAX}'
            eval MARIADB55_BACKUP_${count}_FORCE='${MARIADB_BACKUP_'${count}'_FORCE}'
        fi

        printvar 'MARIADB55_BACKUP_'${count}'_NAME'
        printcomment        'Use a name, ist only for you'

        printvar 'MARIADB55_BACKUP_'${count}'_ACTIVE'
        printcomment        'Use yes or no'

        printvar 'MARIADB55_BACKUP_'${count}'_FILE'
        printcomment        'backup file'

        printvar 'MARIADB55_BACKUP_'${count}'_MAX'
        printcomment        'maximum number of stored Backups'

        printvar 'MARIADB55_BACKUP_'${count}'_FORCE'
        printcomment        'Ignore last file update date'
        count=$((${count} + 1))
    done

    if ${old_conf:-false}
    then
        MARIADB55_BACKUP_MOUNT="${MARIADB_BACKUP_MOUNT}"
        MARIADB55_BACKUP_UMOUNT="${MARIADB_BACKUP_UMOUNT}"
    fi

    printvar 'MARIADB55_BACKUP_MOUNT'
    printcomment            'command before run backup'
    printcomment            "sample: 'mount /mo'"

    printvar 'MARIADB55_BACKUP_UMOUNT'
    printcomment            'command after run backup'
    printcomment            "sample: 'umount /mo'"


    # -----------------------------------------------------------------------
    printgroup 'Special settings'
    # -----------------------------------------------------------------------


    if ${old_conf:-false}
    then
        MARIADB55_DEFAULT_COLLATION="${MARIADB_DEFAULT_COLLATION}"
        MARIADB55_BIND_IP_ADDRESS="${MARIADB_BIND_IP_ADDRESS}"
        MARIADB55_MEMORY_OPT="${MARIADB_MEMORY_OPT}"
        MARIADB55_THREAD_STACK_SIZE="${MARIADB_THREAD_STACK_SIZE}"
        MARIADB55_MAX_ALLOWED_PACKET="${MARIADB_MAX_ALLOWED_PACKET}"
        MARIADB55_MAX_CONNECTIONS="${MARIADB_MAX_CONNECTIONS}"
        MARIADB55_ACTIVATE_BINLOG="${MARIADB_ACTIVATE_BINLOG}"
        MARIADB55_MAX_BINLOG_SIZE="${MARIADB_MAX_BINLOG_SIZE}"

        stack_size=$(echo ${MARIADB55_THREAD_STACK_SIZE} | sed 's#k##')

        if [ ${stack_size:-0} -lt 256 ]
        then
            MARIADB55_THREAD_STACK_SIZE='256k'
        fi
    fi

    printvar 'MARIADB55_DEFAULT_COLLATION'
    printcomment            'Default collation'

    printvar 'MARIADB55_BIND_IP_ADDRESS'
    printcomment            "Network IP Address default=''"
    printcomment            'connect a specific network card'

    printvar 'MARIADB55_MEMORY_OPT'
    printcomment            'Use RAM'
    printcomment            'small:  < 64 MB RAM'
    printcomment            'medium: 64 - 128 MB RAM'
    printcomment            'large:  ~ 512 MB RAM'
    printcomment            'huge:   ~ 1024 MB RAM'

    printvar 'MARIADB55_THREAD_STACK_SIZE'
    printcomment            'stack size in k'

    printvar 'MARIADB55_MAX_ALLOWED_PACKET'
    printcomment            'Default 1 (MB)'

    printvar 'MARIADB55_MAX_CONNECTIONS'
    printcomment            'Count of maximal connections'

    printvar 'MARIADB55_ACTIVATE_BINLOG'
    printcomment            'Activate binary logfile for replication'

    printvar 'MARIADB55_MAX_BINLOG_SIZE'
    printcomment            'Maximum size of logfile in Bytes'


    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------

    } > $internal_conf_file
    # Set rights
    chmod 0600 $internal_conf_file
    chown root $internal_conf_file
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2015-09-18' 'hbfl' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                      OPT_VARIABLE              VARIABLE_N         VALUE
START_MARIADB55                 -                         -                  YESNO

MARIADB55_NETWORK               START_MARIADB55           -                  YESNO
MARIADB55_CONNECT_PORT          START_MARIADB55           -                  MYSQL_COMMON_PORT_CUI

MARIADB55_DATADIR               START_MARIADB55           -                  E_ABS_PATH
MARIADB55_SEND_MAIL_FROM        START_MARIADB55           -                  EMAILADDR
MARIADB55_BACKUP_SCHEDULE_TIME  START_MARIADB55           -                  ON_CALENDAR
MARIADB55_BACKUP_TARGET         START_MARIADB55           -                  ABS_PATH
MARIADB55_BACKUP_GROUP          START_MARIADB55           -                  MARIADB55_GROUP
MARIADB55_BACKUP_N              START_MARIADB55           -                  NUMERIC
MARIADB55_BACKUP_%_NAME         START_MARIADB55           MARIADB55_BACKUP_N NONE
MARIADB55_BACKUP_%_ACTIVE       START_MARIADB55           MARIADB55_BACKUP_N YESNO
MARIADB55_BACKUP_%_FILE         MARIADB55_BACKUP_%_ACTIVE MARIADB55_BACKUP_N MYSQL_COMMON_SELECT_CUI
MARIADB55_BACKUP_%_FILE         MARIADB55_BACKUP_%_ACTIVE MARIADB55_BACKUP_N NOTEMPTY
MARIADB55_BACKUP_%_MAX          MARIADB55_BACKUP_%_ACTIVE MARIADB55_BACKUP_N NUMERIC
MARIADB55_BACKUP_%_FORCE        MARIADB55_BACKUP_%_ACTIVE MARIADB55_BACKUP_N YESNO
MARIADB55_BACKUP_MOUNT          START_MARIADB55           -                  NONE
MARIADB55_BACKUP_UMOUNT         START_MARIADB55           -                  NONE
MARIADB55_DEFAULT_COLLATION     START_MARIADB55           -                  MYSQL_COMMON_DEFCOLL_CUI
MARIADB55_BIND_IP_ADDRESS       START_MARIADB55           -                  EIPADDR
MARIADB55_MEMORY_OPT            START_MARIADB55           -                  MYSQL_COMMON_RAM_CUI
MARIADB55_THREAD_STACK_SIZE     START_MARIADB55           -                  NOTEMPTY
MARIADB55_MAX_ALLOWED_PACKET    START_MARIADB55           -                  NUMERIC
MARIADB55_MAX_CONNECTIONS       START_MARIADB55           -                  NUMERIC
MARIADB55_ACTIVATE_BINLOG       START_MARIADB55           -                  YESNO
MARIADB55_MAX_BINLOG_SIZE       MARIADB55_ACTIVATE_BINLOG -                  NUMERIC
EOF

    # Set rights for check.d file
    chmod 0600 /etc/check.d/${package_name}
    chown root /etc/check.d/${package_name}


printgpl --check_exp ${package_name} '2015-09-18' 'hbfl' >/etc/check.d/${package_name}.exp
cat >>/etc/check.d/${package_name}.exp <<EOF
MYSQL_COMMON_RAM_CUI     = 'small|medium|large|huge'
                         : 'Use only: small, medium, large or huge'
MYSQL_COMMON_DEFCOLL_CUI = '(RE:NOTEMPTY)'
                         : 'Use: latin1_bin latin1_danish_ci latin1_general_ci latin1_general_cs latin1_german1_ci latin1_german2_ci latin1_spanish_ci latin1_swedish_ci utf8_general_ci utf8_unicode_ci utf8_bin latin2_general_ci latin2_bin latin2_hungarian_ci utf8mb4_unicode_ci utf8mb4_general_ci utf8mb4_bin'
MYSQL_COMMON_SELECT_CUI  = '(RE:NOTEMPTY)'
                         : 'Select an existing database.'
MARIADB55_GROUP          = '()|(RE:NONE)'
                         : 'default: empty -> mysql, or your backupgroup'
MYSQL_COMMON_PORT_CUI    = '(RE:PORT)'
                         : 'Port 3306, 3307 ...'
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.exp
    chown root /etc/check.d/${package_name}.exp

printgpl --check_ext ${package_name} '2016-01-17' 'hbfl' >/etc/check.d/${package_name}.ext
cat >>/etc/check.d/${package_name}.ext <<EOF

if (mariadb55_send_mail_from)
then
    set mail = "no"
    stat("/usr/sbin/sendmail", res)
    if (res_res == "OK")
    then
        set mail
    fi

    if (!mail)
    then
        error "No mail package found, please install any mail package before you activate MARIADB55_SEND_MAIL_FROM !"
    fi
fi
EOF

    # Set rights for check.exp file
    chmod 0600 /etc/check.d/${package_name}.ext
    chown root /etc/check.d/${package_name}.ext
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}
# ---------------------------------------------------------------------------
# exec main
# ---------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
